"""
The players of the game
"""

#from treeai   import *
from player   import *
from human    import *
from minmax   import *
from multiplayer import *
from strategic import *
#from agressive import *
from weighted import *
from randomai import *
